# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.1

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_windows_devices_sms

__all__ = [
    "CellularClass",
    "SmsBroadcastType",
    "SmsDataFormat",
    "SmsDeviceStatus",
    "SmsEncoding",
    "SmsFilterActionType",
    "SmsGeographicalScope",
    "SmsMessageClass",
    "SmsMessageFilter",
    "SmsMessageType",
    "SmsModemErrorCode",
    "SmsEncodedLength",
    "DeleteSmsMessageOperation",
    "DeleteSmsMessagesOperation",
    "GetSmsDeviceOperation",
    "GetSmsMessageOperation",
    "GetSmsMessagesOperation",
    "SendSmsMessageOperation",
    "SmsAppMessage",
    "SmsBinaryMessage",
    "SmsBroadcastMessage",
    "SmsDevice",
    "SmsDevice2",
    "SmsDeviceMessageStore",
    "SmsFilterRule",
    "SmsFilterRules",
    "SmsMessageReceivedEventArgs",
    "SmsMessageReceivedTriggerDetails",
    "SmsMessageRegistration",
    "SmsReceivedEventDetails",
    "SmsSendMessageResult",
    "SmsStatusMessage",
    "SmsTextMessage",
    "SmsTextMessage2",
    "SmsVoicemailMessage",
    "SmsWapMessage",
    "ISmsBinaryMessage",
    "ISmsDevice",
    "ISmsMessage",
    "ISmsMessageBase",
    "ISmsTextMessage",
    "SmsDeviceStatusChangedEventHandler",
    "SmsMessageReceivedEventHandler",
]

class CellularClass(enum.IntEnum):
    NONE = 0
    GSM = 1
    CDMA = 2

class SmsBroadcastType(enum.IntEnum):
    OTHER = 0
    CMAS_PRESIDENTIAL = 1
    CMAS_EXTREME = 2
    CMAS_SEVERE = 3
    CMAS_AMBER = 4
    CMAS_TEST = 5
    E_U_ALERT1 = 6
    E_U_ALERT2 = 7
    E_U_ALERT3 = 8
    E_U_ALERT_AMBER = 9
    E_U_ALERT_INFO = 10
    ETWS_EARTHQUAKE = 11
    ETWS_TSUNAMI = 12
    ETWS_TSUNAMI_AND_EARTHQUAKE = 13
    LAT_ALERT_LOCAL = 14

class SmsDataFormat(enum.IntEnum):
    UNKNOWN = 0
    CDMA_SUBMIT = 1
    GSM_SUBMIT = 2
    CDMA_DELIVER = 3
    GSM_DELIVER = 4

class SmsDeviceStatus(enum.IntEnum):
    OFF = 0
    READY = 1
    SIM_NOT_INSERTED = 2
    BAD_SIM = 3
    DEVICE_FAILURE = 4
    SUBSCRIPTION_NOT_ACTIVATED = 5
    DEVICE_LOCKED = 6
    DEVICE_BLOCKED = 7

class SmsEncoding(enum.IntEnum):
    UNKNOWN = 0
    OPTIMAL = 1
    SEVEN_BIT_ASCII = 2
    UNICODE = 3
    GSM_SEVEN_BIT = 4
    EIGHT_BIT = 5
    LATIN = 6
    KOREAN = 7
    I_A5 = 8
    SHIFT_JIS = 9
    LATIN_HEBREW = 10

class SmsFilterActionType(enum.IntEnum):
    ACCEPT_IMMEDIATELY = 0
    DROP = 1
    PEEK = 2
    ACCEPT = 3

class SmsGeographicalScope(enum.IntEnum):
    NONE = 0
    CELL_WITH_IMMEDIATE_DISPLAY = 1
    LOCATION_AREA = 2
    PLMN = 3
    CELL = 4

class SmsMessageClass(enum.IntEnum):
    NONE = 0
    CLASS0 = 1
    CLASS1 = 2
    CLASS2 = 3
    CLASS3 = 4

class SmsMessageFilter(enum.IntEnum):
    ALL = 0
    UNREAD = 1
    READ = 2
    SENT = 3
    DRAFT = 4

class SmsMessageType(enum.IntEnum):
    BINARY = 0
    TEXT = 1
    WAP = 2
    APP = 3
    BROADCAST = 4
    VOICEMAIL = 5
    STATUS = 6

class SmsModemErrorCode(enum.IntEnum):
    OTHER = 0
    MESSAGING_NETWORK_ERROR = 1
    SMS_OPERATION_NOT_SUPPORTED_BY_DEVICE = 2
    SMS_SERVICE_NOT_SUPPORTED_BY_NETWORK = 3
    DEVICE_FAILURE = 4
    MESSAGE_NOT_ENCODED_PROPERLY = 5
    MESSAGE_TOO_LARGE = 6
    DEVICE_NOT_READY = 7
    NETWORK_NOT_READY = 8
    INVALID_SMSC_ADDRESS = 9
    NETWORK_FAILURE = 10
    FIXED_DIALING_NUMBER_RESTRICTED = 11

SmsEncodedLength = _winrt_windows_devices_sms.SmsEncodedLength
DeleteSmsMessageOperation = _winrt_windows_devices_sms.DeleteSmsMessageOperation
DeleteSmsMessagesOperation = _winrt_windows_devices_sms.DeleteSmsMessagesOperation
GetSmsDeviceOperation = _winrt_windows_devices_sms.GetSmsDeviceOperation
GetSmsMessageOperation = _winrt_windows_devices_sms.GetSmsMessageOperation
GetSmsMessagesOperation = _winrt_windows_devices_sms.GetSmsMessagesOperation
SendSmsMessageOperation = _winrt_windows_devices_sms.SendSmsMessageOperation
SmsAppMessage = _winrt_windows_devices_sms.SmsAppMessage
SmsBinaryMessage = _winrt_windows_devices_sms.SmsBinaryMessage
SmsBroadcastMessage = _winrt_windows_devices_sms.SmsBroadcastMessage
SmsDevice = _winrt_windows_devices_sms.SmsDevice
SmsDevice2 = _winrt_windows_devices_sms.SmsDevice2
SmsDeviceMessageStore = _winrt_windows_devices_sms.SmsDeviceMessageStore
SmsFilterRule = _winrt_windows_devices_sms.SmsFilterRule
SmsFilterRules = _winrt_windows_devices_sms.SmsFilterRules
SmsMessageReceivedEventArgs = _winrt_windows_devices_sms.SmsMessageReceivedEventArgs
SmsMessageReceivedTriggerDetails = _winrt_windows_devices_sms.SmsMessageReceivedTriggerDetails
SmsMessageRegistration = _winrt_windows_devices_sms.SmsMessageRegistration
SmsReceivedEventDetails = _winrt_windows_devices_sms.SmsReceivedEventDetails
SmsSendMessageResult = _winrt_windows_devices_sms.SmsSendMessageResult
SmsStatusMessage = _winrt_windows_devices_sms.SmsStatusMessage
SmsTextMessage = _winrt_windows_devices_sms.SmsTextMessage
SmsTextMessage2 = _winrt_windows_devices_sms.SmsTextMessage2
SmsVoicemailMessage = _winrt_windows_devices_sms.SmsVoicemailMessage
SmsWapMessage = _winrt_windows_devices_sms.SmsWapMessage
ISmsBinaryMessage = _winrt_windows_devices_sms.ISmsBinaryMessage
ISmsDevice = _winrt_windows_devices_sms.ISmsDevice
ISmsMessage = _winrt_windows_devices_sms.ISmsMessage
ISmsMessageBase = _winrt_windows_devices_sms.ISmsMessageBase
ISmsTextMessage = _winrt_windows_devices_sms.ISmsTextMessage
SmsDeviceStatusChangedEventHandler = typing.Callable[[typing.Optional[SmsDevice]], None]
SmsMessageReceivedEventHandler = typing.Callable[[typing.Optional[SmsDevice], typing.Optional[SmsMessageReceivedEventArgs]], None]
